function RheoData = ISR_Plotting_results(RheoData,cal)
% Plotting the results of the 

% Iteration over all Pi and creates one figure for each surface pressure
% and shows G, eta, Bo, (G',G''), (eta',eta'') and theta as function of
% omega

for ii = 3:length(RheoData.Sheets)
omega = RheoData.(RheoData.Sheets{ii}).CurrentFrequency_Hz_;
Pi = RheoData.(RheoData.Sheets{ii}).SurfacePressure_mN_m_;
notConvidx = find(RheoData.(RheoData.Sheets{ii}).status_converged==0);

figure(ii) 
subplot(2,3,1)
% plot the interfacial complex modulus as functino of frequency
loglog(omega,RheoData.(RheoData.Sheets{ii}).NonLinG_star_Pam_,'o',...
       omega(notConvidx),RheoData.(RheoData.Sheets{ii}).NonLinG_star_Pam_(notConvidx),'xr','MarkerFaceColor','w','Linewidth',2,'MarkerSize',8)

title(RheoData.Sheets{ii},'Interpreter','none')
xlabel('\omega (Hz)')
ylabel('|G_s^{\ast}| (Pa.m)')
set(gca,'FontSize',16)
%legend('Non-Linear corrected','Location','SouthEast')
%ylim([1e-10,inf])


subplot(2,3,2)
% plot the interfacial complex  viscosity as functino of frequency
loglog(omega,RheoData.(RheoData.Sheets{ii}).NonLinEta_star_Pams_,'o',...
       omega(notConvidx),RheoData.(RheoData.Sheets{ii}).NonLinEta_star_Pams_(notConvidx),'xr','MarkerFaceColor','w','Linewidth',2,'MarkerSize',8)
title(['\Pi = ' num2str(mean(Pi),'%.2f') '\pm' num2str(std(Pi),'%.2f') ' mN/m'])
xlabel('\omega (Hz)')
ylabel('|\eta_s^{\ast}| (Pa.m.s)')
set(gca,'FontSize',16)
%legend('Raw','Linear corrected','Non-Linear corrected','Location','Southeast')
%ylim([1e-10,inf])


subplot(2,3,3)
% plot the complex Bo number as functino of frequency
loglog(omega,RheoData.(RheoData.Sheets{ii}).NonLinBo,'o',...
       omega(notConvidx),RheoData.(RheoData.Sheets{ii}).NonLinBo(notConvidx),'xr','MarkerFaceColor','w','Linewidth',2,'MarkerSize',8)

xlabel('\omega (Hz)')
ylabel('|Bo^*| (-)')
set(gca,'FontSize',16)
%legend('Raw','Linear corrected','Non-Linear corrected','Location','Southeast')
%ylim([1e-1,inf])


subplot(2,3,4)
% plot the interfacial storage and loss moduli as functino of frequency
loglog(omega,RheoData.(RheoData.Sheets{ii}).NonLinReG_Pam_,'<m',...
       omega,RheoData.(RheoData.Sheets{ii}).NonLinImG_Pam_,'>c',...
       omega(notConvidx),RheoData.(RheoData.Sheets{ii}).NonLinReG_Pam_(notConvidx),'xr',...
       omega(notConvidx),RheoData.(RheoData.Sheets{ii}).NonLinImG_Pam_(notConvidx),'xr','MarkerFaceColor','w','Linewidth',2,'MarkerSize',8)

xlabel('\omega (Hz)')
ylabel('G^{\prime}_s, G^{\prime\prime}_s (Pa.m)')
legend('G^{\prime}_s','G^{\prime\prime}_s','Location','best')
set(gca,'FontSize',16)
%ylim([1e-10,inf])


subplot(2,3,5)
% plot the interfacial shear and dilataionoal viscosities as functino of frequency
loglog(omega,RheoData.(RheoData.Sheets{ii}).NonLinReEta_Pams_,'>c',...
       omega,RheoData.(RheoData.Sheets{ii}).NonLinImEta_Pams_,'<m',...
       omega(notConvidx),RheoData.(RheoData.Sheets{ii}).NonLinReEta_Pams_(notConvidx),'xr',...
       omega(notConvidx),RheoData.(RheoData.Sheets{ii}).NonLinImEta_Pams_(notConvidx),'xr','MarkerFaceColor','w','Linewidth',2,'MarkerSize',8)

xlabel('\omega (Hz)')
ylabel('\eta^{\prime}_s, \eta^{\prime\prime}_s (Pa.m.s)')
legend('\eta^{\prime}_s','\eta^{\prime\prime}_s','Location','best')
set(gca,'FontSize',16)



subplot(2,3,6)
% plot the interfacial phase angle as functino of frequency
semilogx(omega,RheoData.(RheoData.Sheets{ii}).NonLinDelta_deg_,'o',...
         omega,RheoData.(RheoData.Sheets{ii}).MeasuredDelta_deg_,'sg',...
         omega(notConvidx),RheoData.(RheoData.Sheets{ii}).NonLinDelta_deg_(notConvidx),'xr','MarkerFaceColor','w','Linewidth',2,'MarkerSize',8)

xlabel('\omega (Hz)')
ylabel('\delta_s (\circ)')
legend('Corrected','Measured','Location','best')
set(gca,'FontSize',16)

savefig(ii,fullfile(cal.path,'Analysis',strcat('Results_',RheoData.Sheets{ii},date,'.fig')));


end
end