function ISR_analysis_masterfile(handles)
% Analysis of ISR measurements
%
%clear 
%close all
clc
addpath(genpath(pwd)) % in order to find the functions in the subfolder

disp('Begining with ISR analysis-------------------------------------------')

% This vector decides what has to be done:
%       DO(1)..Calibration
%       DO(2)..Non-Linear Correction
%

DO = [handles.Box_calibration.Value handles.Box_NonlinCorr.Value]; 


% format:
%   Freq of Voltage | Amplitude ratio | Phase shift | Freq of rod edge
%       (Hz)             (pixel/V)          (deg)        (Hz)

% if ismac
%     Path = fullfile('/Users','damianrenggli','Documents','Polybox','ETH','PhD','ResearchPlan','Results');
%     file_del = find(Path==filesep);
% else
%     Path = fullfile('/home','rengglid','Documents','Measurements');
%     file_del = find(Path==filesep);
% end
% 
% handles.input.path=Path;
% handles.edit_limit.String = '1e-5';

%% Calibration %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if DO(1)==1
    
disp('Calibrating ... ... ...')

% Import calibration Data 
% Initialize variabel and get file name & path
cal = struct('file',handles.input.file,'path',handles.input.path,'parameters',[],'data',[],'model',[]);

% import data
cal.parameters = readtable(fullfile(cal.path,cal.file),'Sheet',1); % This sheet should be called exactly "CalibrationParameter"
cal.data       = readtable(fullfile(cal.path,cal.file),'Sheet',2); % This sheet should be called exactly "CalibrationData"

% Do calibration
cal = ISR_Calibration_subphase(cal);

% Write output to file
save(fullfile(cal.path,'Analysis',strcat('calibration_',date,'.mat')),'cal');
disp('Calibration has been performed---------------------------------------')
end




%% Non-Linear Correction %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if DO(2)==1
disp('Non-Linear Correction ... ... ...')
% Import Raw measuring Data:

% load the calibration file in case the calibration has been done some time
% before the subphase correction.

if DO(1)~=1
    [input.file, input.path] = uigetfile(fullfile(handles.input.path,'calibration*.mat'),'Please select the Mat file containing the calibration.','multiselect','off');
    load(fullfile(input.path,input.file))
end
    

% find the names of the worksheets containing the rheological data
[Status,Sheets] = xlsfinfo(fullfile(cal.path,cal.file)); % The following sheets should be named similar to "RheoData_Pi09" or "Rheo_Pi09"
% load the data
for i= 3 :length(Sheets)
    RheoData.(matlab.lang.makeValidName(Sheets{i})) = readtable(fullfile(cal.path,cal.file),'Sheet',Sheets{i}); 
end
RheoData.Sheets = Sheets;
    


% prepare data for subphase correction of each sheet
h = waitbar(0,sprintf('Calculating the subphase correction... \nExcel sheet %g of %g', 0,length(RheoData.Sheets)-2));
tic
for i = 3:length(RheoData.Sheets)
    mkdir(fullfile(cal.path,'Analysis',RheoData.Sheets{i}));
    %Data = RheoData.(RheoData.Sheets{i});
    %lim = str2double(handles.edit_limit.String);
    [RheoData.(RheoData.Sheets{i})] = ISR_NonLinearCorrection(RheoData.(RheoData.Sheets{i}),cal,str2double(handles.edit_limit.String),RheoData.Sheets{i});
    waitbar((i-2)/(length(RheoData.Sheets)-2),h,...
        sprintf('Calculating the subphase correction... \nExcel sheet %g of %g, t = %g s', i-2,length(RheoData.Sheets)-2,toc));
end
close(h);
%close(1);


% Write output to file
save(fullfile(cal.path,'Analysis',strcat('NonlinearCorrection_',date,'.mat')), 'RheoData');
disp('Non-Linear Correction has been performed-----------------------------')
end

%% Saving DATA:
% Write output to file
if DO(1)==1
    writetable(cal.parameters,fullfile(cal.path,cal.file),'Sheet','CalibrationParameters')
    writetable(cal.data,fullfile(cal.path,cal.file),'Sheet','CalibrationData')
end


if DO(2) ==1
    for i=3:length(RheoData.Sheets)
        writetable(RheoData.(RheoData.Sheets{i}),fullfile(cal.path,cal.file),'Sheet',RheoData.Sheets{i})
    end
end




%% Plotting the results

clf
% this function creates one figure for each sheet in the specified Excel
% sheet as function of ther surface pressure
if DO(2)==1
ISR_Plotting_results(RheoData,cal);
end






